@@ -51,7 +51,7 @@ class ThumbnailBarView;
 class FullScreenConfigWidget : public QWidget, public Ui_FullScreenConfigWidget
 {
 public:
-    FullScreenConfigWidget(QWidget* parent=0)
+    explicit FullScreenConfigWidget(QWidget* parent=nullptr)
     : QWidget(parent)
     {
         setupUi(this);
@@ -92,6 +92,7 @@ private Q_SLOTS:
     void slotShowThumbnailsToggled(bool value);
     void slotViewModeActionToggled(bool value);
     void adjustSize();
+    void updateDocumentCountLabel();
 
 private:
     KActionCollection* mActionCollection;
@@ -102,14 +103,17 @@ private:
     FullScreenToolBar* mRightToolBar;
     ThumbnailBarView* mThumbnailBar;
     QLabel* mInformationLabel;
+    QLabel* mDocumentCountLabel;
+    QWidget* mInformationContainer;
     ShadowFilter* mToolBarShadow;
     ShadowFilter* mRightToolBarShadow;
-    ShadowFilter* mInformationLabelShadow;
+    ShadowFilter* mInformationContainerShadow;
     Document::Ptr mCurrentDocument;
     QPointer<ImageMetaInfoDialog> mImageMetaInfoDialog;
     QPointer<FullScreenConfigWidget> mConfigWidget;
     QAction * mOptionsAction;
     GvCore* mGvCore;
+    int mMinimumThumbnailBarHeight;
 
     bool mViewPageVisible;
 
