@@ -30,6 +30,8 @@ class QModelIndex;
 
 class QUrl;
 
+class QMouseEvent;
+
 namespace Gwenview
 {
 
@@ -79,6 +81,8 @@ protected:
     void saveProperties(KConfigGroup&) override;
     void readProperties(const KConfigGroup&) override;
     bool eventFilter(QObject *, QEvent *) override;
+    void mousePressEvent(QMouseEvent *) override;
+    void mouseDoubleClickEvent(QMouseEvent *) override;
 
 private Q_SLOTS:
     void setActiveViewModeAction(QAction* action);
@@ -128,6 +132,8 @@ private Q_SLOTS:
 
     void showFirstDocumentReached();
     void showLastDocumentReached();
+    
+    void replaceLocation();
 
 private:
     struct Private;
@@ -137,6 +143,8 @@ private:
     void saveConfig();
     void configureShortcuts();
 
+    void mouseButtonNavigate(QMouseEvent *);
+
     void folderViewUrlChanged(const QUrl &url);
 };
 
