@@ -154,7 +154,7 @@ struct SaveBarPrivate
         qreal maxPercentageOfMemoryUsage = GwenviewConfig::percentageOfMemoryUsageWarning();
         qulonglong maxMemoryUsage = MemoryUtils::getTotalMemory() * maxPercentageOfMemoryUsage;
         qulonglong memoryUsage = 0;
-        Q_FOREACH(const QUrl &url, list) {
+        for (const QUrl &url : list) {
             Document::Ptr doc = DocumentFactory::instance()->load(url);
             memoryUsage += doc->memoryUsage();
         }
@@ -270,7 +270,7 @@ SaveBar::SaveBar(QWidget* parent, KActionCollection* actionCollection)
     QVBoxLayout* layout = new QVBoxLayout(d->mSaveBarWidget);
     layout->addWidget(d->mTopRowWidget);
     layout->addLayout(bottomRowLayout);
-    layout->setMargin(3);
+    layout->setContentsMargins(3, 3, 3, 3);
     layout->setSpacing(3);
 
     setContent(d->mSaveBarWidget);
