@@ -19,16 +19,16 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "dialogpage.moc"
+#include "dialogpage.h"
 
 // Qt
 #include <QEventLoop>
 #include <QList>
-#include <QSignalMapper>
 #include <QVBoxLayout>
+#include <QPushButton>
 
 // KDE
-#include <KPushButton>
+#include <KGuiItem>
 
 // Local
 #include <ui_dialogpage.h>
@@ -39,8 +39,7 @@ namespace Gwenview
 struct DialogPagePrivate : public Ui_DialogPage
 {
     QVBoxLayout* mLayout;
-    QList<KPushButton*> mButtons;
-    QSignalMapper* mMapper;
+    QList<QPushButton*> mButtons;
     QEventLoop* mEventLoop;
 };
 
@@ -50,8 +49,6 @@ DialogPage::DialogPage(QWidget* parent)
 {
     d->setupUi(this);
     d->mLayout = new QVBoxLayout(d->mButtonContainer);
-    d->mMapper = new QSignalMapper(this);
-    connect(d->mMapper, SIGNAL(mapped(int)), SLOT(slotMapped(int)));
 }
 
 DialogPage::~DialogPage()
@@ -73,12 +70,14 @@ void DialogPage::setText(const QString& text)
 int DialogPage::addButton(const KGuiItem& item)
 {
     int id = d->mButtons.size();
-    KPushButton* button = new KPushButton(item);
+    QPushButton* button = new QPushButton;
+    KGuiItem::assign(button, item);
     button->setFixedHeight(button->sizeHint().height() * 2);
 
-    connect(button, SIGNAL(clicked()), d->mMapper, SLOT(map()));
+    connect(button, &QAbstractButton::clicked, this, [this, id]() {
+        d->mEventLoop->exit(id);
+    });
     d->mLayout->addWidget(button);
-    d->mMapper->setMapping(button, id);
     d->mButtons << button;
     return id;
 }
@@ -90,9 +89,4 @@ int DialogPage::exec()
     return loop.exec();
 }
 
-void DialogPage::slotMapped(int value)
-{
-    d->mEventLoop->exit(value);
-}
-
 } // namespace
