@@ -39,16 +39,13 @@ class DialogPage : public QWidget
     Q_OBJECT
 public:
     explicit DialogPage(QWidget* parent = nullptr);
-    ~DialogPage();
+    ~DialogPage() override;
 
     void removeButtons();
     void setText(const QString&);
     int addButton(const KGuiItem&);
     int exec();
 
-private Q_SLOTS:
-    void slotMapped(int);
-
 private:
     DialogPagePrivate* const d;
 };
