@@ -35,11 +35,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <KIO/JobUiDelegate>
 #include <KJobWidgets>
 
-// libc
-#include <errno.h>
-#include <stdlib.h>
-#include <string.h>
-
 namespace Gwenview
 {
 namespace FileUtils
@@ -144,19 +139,5 @@ RenameResult rename(const QUrl& src, const QUrl& dst_, QWidget* authWindow)
     return result;
 }
 
-QString createTempDir(const QString& baseDir, const QString& prefix, QString* errorMessage)
-{
-    Q_ASSERT(errorMessage);
-
-    QByteArray name = QFile::encodeName(baseDir + '/' + prefix + "XXXXXX");
-
-    if (!mkdtemp(name.data())) {
-        // Failure
-        *errorMessage = QString::fromLocal8Bit(::strerror(errno));
-        return QString();
-    }
-    return QFile::decodeName(name + '/');
-}
-
 } // namespace
 } // namespace
