@@ -25,11 +25,13 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QDateTime>
 #include <QDebug>
 #include <QUrl>
+#include <QTemporaryDir>
 
 // KDE
 #include <KFileItem>
 #include <KIO/CopyJob>
 #include <KIO/DeleteJob>
+#include <KIO/MkpathJob>
 #include <KIO/Job>
 #include <KIO/JobUiDelegate>
 #include <KJobWidgets>
@@ -53,6 +55,7 @@ struct ImporterPrivate
     QWidget* mAuthWindow;
     std::unique_ptr<FileNameFormater> mFileNameFormater;
     QUrl mTempImportDirUrl;
+    QTemporaryDir* mTempImportDir;
 
     /* @defgroup reset Should be reset in start()
      * @{ */
@@ -75,13 +78,21 @@ struct ImporterPrivate
             emit q->error(i18n("Could not create destination folder."));
             return false;
         }
-        QString message;
-        QString dir = FileUtils::createTempDir(url.toLocalFile(), ".gwenview_importer-", &message);
-        mTempImportDirUrl = QUrl::fromLocalFile(dir);
-        if (mTempImportDirUrl.isEmpty()) {
-            emit q->error(i18n("Could not create temporary upload folder:\n%1", message));
+        
+        QString tempDirPath = url.toLocalFile() + "/.gwenview_importer-XXXXXX";
+        mTempImportDir = new QTemporaryDir(tempDirPath);
+                    
+        if (!mTempImportDir->isValid()) {
+            emit q->error(i18n("Could not create temporary upload folder."));
             return false;
         }
+        
+        mTempImportDirUrl = QUrl::fromLocalFile(mTempImportDir->path() + '/');
+        if (!mTempImportDirUrl.isValid()) {
+            emit q->error(i18n("Could not create temporary upload folder."));
+            return false;
+        }         
+        
         return true;
     }
 
@@ -120,7 +131,18 @@ struct ImporterPrivate
         }
         dst.setPath(dst.path() + fileName);
 
-        FileUtils::RenameResult result = FileUtils::rename(src, dst, mAuthWindow);
+        FileUtils::RenameResult result;
+        // Create additional subfolders if needed (e.g. when extra slashes in FileNameFormater)
+        QUrl subFolder = dst.adjusted(QUrl::RemoveFilename);
+        KIO::Job* job = KIO::mkpath(subFolder, QUrl(), KIO::HideProgressInfo);
+        KJobWidgets::setWindow(job,mAuthWindow);
+        if (!job->exec()) { // if subfolder creation fails
+            qWarning() << "Could not create subfolder:" << subFolder;
+            result = FileUtils::RenameFailed;
+        } else { // if subfolder creation succeeds
+            result = FileUtils::rename(src, dst, mAuthWindow);
+        }
+
         switch (result) {
         case FileUtils::RenamedOK:
             mImportedUrlList << mCurrentUrl;
@@ -197,8 +219,7 @@ void Importer::slotCopyDone(KJob* _job)
 
 void Importer::finalizeImport()
 {
-    KIO::Job* job = KIO::del(d->mTempImportDirUrl, KIO::HideProgressInfo);
-    KJobWidgets::setWindow(job, d->mAuthWindow);
+    delete d->mTempImportDir;
     emit importFinished();
 }
 
