@@ -127,7 +127,7 @@ struct CropToolPrivate
 
     CropHandle handleAt(const QPointF& pos)
     {
-        Q_FOREACH(const CropHandle & handle, mCropHandleList) {
+        for (const CropHandle & handle : qAsConst(mCropHandleList)) {
             QRectF rect = handleViewportRect(handle);
             if (rect.contains(pos)) {
                 return handle;
@@ -272,8 +272,8 @@ void CropTool::paint(QPainter* painter)
     static const QColor borderColor = QColor::fromHsvF(0, 0, 1.0);
     static const QColor fillColor   = QColor::fromHsvF(0, 0, 0.75, 0.66);
 
-    QRegion outerRegion = QRegion(imageRect) - QRegion(rect);
-    Q_FOREACH(const QRect & outerRect, outerRegion.rects()) {
+    const QRegion outerRegion = QRegion(imageRect) - QRegion(rect);
+    for (const QRect &outerRect : outerRegion) {
         painter->fillRect(outerRect, outerColor);
     }
 
@@ -284,7 +284,7 @@ void CropTool::paint(QPainter* painter)
     if (d->mMovingHandle == CH_None) {
         // Only draw handles when user is not resizing
         painter->setBrush(fillColor);
-        Q_FOREACH(const CropHandle & handle, d->mCropHandleList) {
+        for (const CropHandle & handle : qAsConst(d->mCropHandleList)) {
             rect = d->handleViewportRect(handle);
             painter->drawRect(rect);
         }
@@ -374,7 +374,7 @@ void CropTool::mouseMoveEvent(QGraphicsSceneMouseEvent* event)
         } else if (d->mMovingHandle & CH_Top) {
             // Top left or top right
             int height = int(d->mRect.width() * ratioToEnforce);
-            d->mRect.setTop(d->mRect.bottom() - height);
+            d->mRect.setTop(d->mRect.y() + d->mRect.height() - height);
         } else if (d->mMovingHandle & CH_Bottom) {
             // Bottom left or bottom right
             int height = int(d->mRect.width() * ratioToEnforce);
