@@ -43,25 +43,26 @@ class GWENVIEWLIB_EXPORT CropTool : public AbstractRasterImageViewTool
     Q_OBJECT
 public:
     CropTool(RasterImageView* parent);
-    ~CropTool() Q_DECL_OVERRIDE;
+    ~CropTool() override;
 
     void setCropRatio(double ratio);
 
     void setRect(const QRect&);
     QRect rect() const;
 
-    void paint(QPainter*) Q_DECL_OVERRIDE;
+    void paint(QPainter*) override;
 
-    void mousePressEvent(QGraphicsSceneMouseEvent*) Q_DECL_OVERRIDE;
-    void mouseMoveEvent(QGraphicsSceneMouseEvent*) Q_DECL_OVERRIDE;
-    void mouseReleaseEvent(QGraphicsSceneMouseEvent*) Q_DECL_OVERRIDE;
-    void hoverMoveEvent(QGraphicsSceneHoverEvent*) Q_DECL_OVERRIDE;
-    void keyPressEvent(QKeyEvent*) Q_DECL_OVERRIDE;
+    void mousePressEvent(QGraphicsSceneMouseEvent*) override;
+    void mouseMoveEvent(QGraphicsSceneMouseEvent*) override;
+    void mouseReleaseEvent(QGraphicsSceneMouseEvent*) override;
+    void mouseDoubleClickEvent(QGraphicsSceneMouseEvent* event) override;
+    void hoverMoveEvent(QGraphicsSceneHoverEvent*) override;
+    void keyPressEvent(QKeyEvent*) override;
 
-    void toolActivated() Q_DECL_OVERRIDE;
-    void toolDeactivated() Q_DECL_OVERRIDE;
+    void toolActivated() override;
+    void toolDeactivated() override;
 
-    QWidget* widget() const Q_DECL_OVERRIDE;
+    QWidget* widget() const override;
 
 Q_SIGNALS:
     void rectUpdated(const QRect&);
