@@ -200,15 +200,18 @@ struct CropWidgetPrivate : public QWidget
 
         addRatioToComboBox(QSizeF(1, 1), i18n("Square"));
         addRatioToComboBox(ratio(QApplication::desktop()->screenGeometry().size()), i18n("This Screen"));
+        // The previous string should be changed to
+        // addRatioToComboBox(ratio(QGuiApplication::screenAt(QCursor::pos())->geometry().size()), i18n("This Screen"));
+        // after switching to Qt > 5.9
         addSectionHeaderToComboBox(i18n("Landscape"));
 
-        Q_FOREACH(const QSizeF& size, ratioList) {
+        for (const QSizeF& size : qAsConst(ratioList)) {
             addRatioToComboBox(size);
         }
         addRatioToComboBox(QSizeF(sqrt2, 1), i18n("ISO (A4, A3...)"));
         addRatioToComboBox(QSizeF(11, 8.5), i18n("US Letter"));
         addSectionHeaderToComboBox(i18n("Portrait"));
-        Q_FOREACH(QSizeF size, ratioList) {
+        for (QSizeF size : qAsConst(ratioList)) {
             size.transpose();
             addRatioToComboBox(size);
         }
@@ -303,7 +306,7 @@ struct CropWidgetPrivate : public QWidget
         box = boxWidget(cropWidget);
         mAdvancedWidgets << box;
         QLabel* label = new QLabel(i18nc("@label:listbox", "Aspect ratio:"), box);
-        label->setMargin(4);
+        label->setContentsMargins(4, 4, 4, 4);
         box->layout()->addWidget(label);
         ratioComboBox = new QComboBox(box);
         ratioComboBox->setEditable(true);
@@ -316,7 +319,7 @@ struct CropWidgetPrivate : public QWidget
         box = boxWidget(cropWidget);
         mAdvancedWidgets << box;
         label = new QLabel(i18nc("@label:spinbox", "Size:"), box);
-        label->setMargin(4);
+        label->setContentsMargins(4, 4, 4, 4);
         box->layout()->addWidget(label);
 
         QHBoxLayout* innerLayout = new QHBoxLayout();
@@ -338,7 +341,7 @@ struct CropWidgetPrivate : public QWidget
         box = boxWidget(cropWidget);
         mAdvancedWidgets << box;
         label = new QLabel(i18nc("@label:spinbox", "Position:"), box);
-        label->setMargin(4);
+        label->setContentsMargins(4, 4, 4, 4);
         box->layout()->addWidget(label);
 
         innerLayout = new QHBoxLayout();
