@@ -71,7 +71,7 @@ static void logQueue(DocumentPrivate* d)
         return;
     }
     qDebug(PREFIX "%d pending job(s):", d->mJobQueue.size());
-    Q_FOREACH(DocumentJob* job, d->mJobQueue) {
+    for (DocumentJob* job : qAsConst(d->mJobQueue)) {
         Q_ASSERT(job);
         qDebug() << PREFIX "-" << job;
     }
@@ -157,8 +157,6 @@ Document::Document(const QUrl &url)
     d->mImpl = nullptr;
     d->mUrl = url;
     d->mKeepRawData = false;
-
-    reload();
 }
 
 Document::~Document()
