@@ -79,8 +79,6 @@ namespace Gwenview
 #define LOG(x) ;
 #endif
 
-const int MIN_PREV_SIZE = 1000;
-
 const int HEADER_SIZE = 256;
 
 struct LoadingDocumentImplPrivate
@@ -196,6 +194,11 @@ struct LoadingDocumentImplPrivate
         buffer.setBuffer(&mData);
         buffer.open(QIODevice::ReadOnly);
 
+        Exiv2ImageLoader loader;
+        if (loader.load(mData)) {
+            mExiv2Image = loader.popImage();
+        }
+
 #ifdef KDCRAW_FOUND
         if (KDcrawIface::KDcraw::rawFilesList().contains(QString::fromLatin1(mFormatHint))) {
             QByteArray previewData;
@@ -207,10 +210,9 @@ struct LoadingDocumentImplPrivate
             // KDcraw functionality cloned locally (temp. solution)
             bool ret = KDcrawIface::KDcraw::loadEmbeddedPreview(previewData, buffer);
 
-            QImage originalImage;
-            if (!ret || !originalImage.loadFromData(previewData) || qMin(originalImage.width(), originalImage.height()) < MIN_PREV_SIZE) {
-                // if the embedded preview loading failed or gets just a small image, load
-                // half preview instead. That's slower but it works even for images containing
+            if (!ret) {
+                // if the embedded preview loading failed, load half preview instead.
+                // That's slower but it works even for images containing
                 // small (160x120px) or none embedded preview.
                 if (!KDcrawIface::KDcraw::loadHalfPreview(previewData, buffer)) {
                     qWarning() << "unable to get half preview for " << q->document()->url().fileName();
@@ -260,11 +262,6 @@ struct LoadingDocumentImplPrivate
         LOG("mFormat" << mFormat);
         GV_RETURN_VALUE_IF_FAIL(!mFormat.isEmpty(), false);
 
-        Exiv2ImageLoader loader;
-        if (loader.load(mData)) {
-            mExiv2Image = loader.popImage();
-        }
-
         if (mFormat == "jpeg" && mExiv2Image.get()) {
             mJpegContent.reset(new JpegContent());
         }
@@ -452,6 +449,12 @@ void LoadingDocumentImpl::slotTransferFinished(KJob* job)
         emit loadingFailed();
         switchToImpl(new EmptyDocumentImpl(document()));
         return;
+    } else if (document()->kind() == MimeTypeUtils::KIND_UNKNOWN) {
+        // Transfer finished. If the mime type is still unknown (e.g. for files < HEADER_SIZE)
+        // determine the kind again.
+        if (d->determineKind()) {
+            return;
+        }
     }
     d->startLoading();
 }
