@@ -33,10 +33,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 class QPropertyAnimation;
 class QUrl;
-class QGestureEvent;
-class QTapGesture;
-class QPinchGesture;
-class QGesture;
 
 namespace Gwenview
 {
