@@ -74,11 +74,11 @@ void RasterImageViewAdapter::setCursor(const QCursor& cursor)
     d->mView->setCursor(cursor);
 }
 
-void RasterImageViewAdapter::setDocument(Document::Ptr doc)
+void RasterImageViewAdapter::setDocument(const Document::Ptr &doc)
 {
     d->mView->setDocument(doc);
 
-    connect(doc.data(), SIGNAL(loadingFailed(QUrl)), SLOT(slotLoadingFailed()));
+    connect(doc.data(), &Document::loadingFailed, this, &RasterImageViewAdapter::slotLoadingFailed);
     if (doc->loadingState() == Document::LoadingFailed) {
         slotLoadingFailed();
     }
