@@ -73,7 +73,7 @@ public:
 
     Document::Ptr document() const override;
 
-    void setDocument(Document::Ptr) override;
+    void setDocument(const Document::Ptr &) override;
 
     void loadConfig() override;
 
