@@ -45,8 +45,8 @@ InvisibleButtonGroup::InvisibleButtonGroup(QWidget* parent)
     hide();
     d->mGroup = new QButtonGroup(this);
     d->mGroup->setExclusive(true);
-    connect(d->mGroup, static_cast<void (QButtonGroup::*)(int)>(&QButtonGroup::buttonClicked), this, &InvisibleButtonGroup::selectionChanged);
-    const QString name = metaObject()->className();
+    connect(d->mGroup, QOverload<int>::of(&QButtonGroup::buttonClicked), this, &InvisibleButtonGroup::selectionChanged);
+    const QString name = QString::fromLatin1(metaObject()->className());
     if (!KConfigDialogManager::propertyMap()->contains(name)) {
         KConfigDialogManager::propertyMap()->insert(name, "current");
         KConfigDialogManager::changedMap()->insert(name, SIGNAL(selectionChanged(int)));
