@@ -42,13 +42,13 @@ class GWENVIEWLIB_EXPORT KindProxyModel : public QSortFilterProxyModel
     Q_OBJECT
 public:
     explicit KindProxyModel(QObject* parent = nullptr);
-    ~KindProxyModel() Q_DECL_OVERRIDE;
+    ~KindProxyModel() override;
 
     void setKindFilter(MimeTypeUtils::Kinds);
     MimeTypeUtils::Kinds kindFilter() const;
 
 protected:
-    bool filterAcceptsRow(int sourceRow, const QModelIndex& sourceParent) const Q_DECL_OVERRIDE;
+    bool filterAcceptsRow(int sourceRow, const QModelIndex& sourceParent) const override;
 
 private:
     KindProxyModelPrivate* const d;
