@@ -42,17 +42,17 @@ class GWENVIEWLIB_EXPORT PreferredImageMetaInfoModel : public QSortFilterProxyMo
     Q_OBJECT
 public:
     PreferredImageMetaInfoModel(ImageMetaInfoModel* model, const QStringList& list);
-    ~PreferredImageMetaInfoModel() Q_DECL_OVERRIDE;
+    ~PreferredImageMetaInfoModel() override;
 
-    QVariant data(const QModelIndex&, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
-    bool setData(const QModelIndex& index, const QVariant& value, int role) Q_DECL_OVERRIDE;
-    Qt::ItemFlags flags(const QModelIndex& index) const Q_DECL_OVERRIDE;
+    QVariant data(const QModelIndex&, int role = Qt::DisplayRole) const override;
+    bool setData(const QModelIndex& index, const QVariant& value, int role) override;
+    Qt::ItemFlags flags(const QModelIndex& index) const override;
 
 Q_SIGNALS:
     void preferredMetaInfoKeyListChanged(const QStringList&);
 
 protected:
-    bool lessThan(const QModelIndex& left, const QModelIndex& right) const Q_DECL_OVERRIDE;
+    bool lessThan(const QModelIndex& left, const QModelIndex& right) const override;
 
 private:
     PreferredImageMetaInfoModelPrivate* const d;
