@@ -47,18 +47,21 @@ public:
     };
 
     explicit RedEyeReductionTool(RasterImageView* parent);
-    ~RedEyeReductionTool() Q_DECL_OVERRIDE;
+    ~RedEyeReductionTool() override;
 
-    void paint(QPainter*) Q_DECL_OVERRIDE;
+    void paint(QPainter*) override;
 
-    void mousePressEvent(QGraphicsSceneMouseEvent*) Q_DECL_OVERRIDE;
-    void mouseMoveEvent(QGraphicsSceneMouseEvent*) Q_DECL_OVERRIDE;
-    void mouseReleaseEvent(QGraphicsSceneMouseEvent*) Q_DECL_OVERRIDE;
-    void keyPressEvent(QKeyEvent*) Q_DECL_OVERRIDE;
+    void mousePressEvent(QGraphicsSceneMouseEvent*) override;
+    void mouseMoveEvent(QGraphicsSceneMouseEvent*) override;
+    void mouseReleaseEvent(QGraphicsSceneMouseEvent*) override;
+    void mouseDoubleClickEvent(QGraphicsSceneMouseEvent* event) override;
+    void keyPressEvent(QKeyEvent*) override;
 
-    void toolActivated() Q_DECL_OVERRIDE;
+    void toolActivated() override;
 
-    QWidget* widget() const Q_DECL_OVERRIDE;
+    void slotApplyClicked();
+
+    QWidget* widget() const override;
 
 Q_SIGNALS:
     void done();
@@ -66,7 +69,6 @@ Q_SIGNALS:
 
 private Q_SLOTS:
     void setDiameter(int);
-    void slotApplyClicked();
 
 private:
     RedEyeReductionToolPrivate* const d;
