@@ -22,7 +22,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include "thumbnailgenerator.h"
 
 // Local
-#include "imageutils.h"
 #include "jpegcontent.h"
 #include "gwenviewconfig.h"
 #include "exiv2imageloader.h"
@@ -50,8 +49,6 @@ namespace Gwenview
 #define LOG(x) ;
 #endif
 
-const int MIN_PREV_SIZE = 1000;
-
 //------------------------------------------------------------------------
 //
 // ThumbnailContext
@@ -61,7 +58,6 @@ bool ThumbnailContext::load(const QString &pixPath, int pixelSize)
 {
     mImage = QImage();
     mNeedCaching = true;
-    Orientation orientation = NORMAL;
     QImage originalImage;
     QSize originalSize;
 
@@ -82,9 +78,8 @@ bool ThumbnailContext::load(const QString &pixPath, int pixelSize)
 
         // We need QImage. Loading JpegContent from QImage - exif lost
         // Loading QImage from JpegContent - unimplemented, would go with loadFromData
-        if (!ret || !originalImage.loadFromData(data) || qMin(originalImage.width(), originalImage.height()) < MIN_PREV_SIZE) {
-            // if the embedded preview loading failed or gets just a small image, load
-            // half preview instead. That's slower...
+        if (!ret) {
+            // if the embedded preview loading failed, load half preview instead. That's slower...
             if (!KDcrawIface::KDcraw::loadHalfPreview(data, pixPath)) {
                 qWarning() << "unable to get preview for " << pixPath.toUtf8().constData();
                 return false;
@@ -118,19 +113,15 @@ bool ThumbnailContext::load(const QString &pixPath, int pixelSize)
     }
 
     // If there's jpeg content (from jpg or raw files), try to load an embedded thumbnail, if available.
-    // If applyExifOrientation is not set, don't use the
-    // embedded thumbnail since it might be rotated differently
-    // than the actual image
-    if (!content.rawData().isEmpty() && GwenviewConfig::applyExifOrientation()) {
+    if (!content.rawData().isEmpty()) {
         QImage thumbnail = content.thumbnail();
-        orientation = content.orientation();
 
-        if (qMax(thumbnail.width(), thumbnail.height()) >= pixelSize) {
-            mImage = thumbnail;
-            if (orientation != NORMAL && orientation != NOT_AVAILABLE) {
-                QTransform matrix = ImageUtils::transformMatrix(orientation);
-                mImage = mImage.transformed(matrix);
-            }
+        // If the user does not care about the generated thumbnails (by deleting them on exit), use ANY
+        // embedded thumnail, even if it's too small.
+        if (!thumbnail.isNull() &&
+            (GwenviewConfig::lowResourceUsageMode() || qMax(thumbnail.width(), thumbnail.height()) >= pixelSize)
+        ) {
+            mImage = std::move(thumbnail);
             mOriginalWidth = content.size().width();
             mOriginalHeight = content.size().height();
             return true;
@@ -281,6 +272,8 @@ void ThumbnailGenerator::run()
                     cacheThumbnail();
                 }
             } else {
+                // avoid emitting the thumb from the previous successful run
+                mImage = QImage();
                 qWarning() << "Could not generate thumbnail for file" << mOriginalUri;
             }
             mPixPath.clear(); // done, ready for next
