@@ -817,7 +817,7 @@ void ThumbnailView::wheelEvent(QWheelEvent* event)
     // setThumbnailSize() does not work
     //verticalScrollBar()->setSingleStep(d->mThumbnailSize / 5);
     if (event->modifiers() == Qt::ControlModifier) {
-        int width = thumbnailSize().width() + (event->delta() > 0 ? 1 : -1) * WHEEL_ZOOM_MULTIPLIER;
+        int width = thumbnailSize().width() + (event->angleDelta().y() > 0 ? 1 : -1) * WHEEL_ZOOM_MULTIPLIER;
         width = qMax(int(MinThumbnailSize), qMin(width, int(MaxThumbnailSize)));
         setThumbnailWidth(width);
     } else {
@@ -976,7 +976,7 @@ void ThumbnailView::updateThumbnailBusyState(const QUrl& url, bool busy)
 
 void ThumbnailView::updateBusyIndexes()
 {
-    Q_FOREACH(const QPersistentModelIndex & index, d->mBusyIndexSet) {
+    for (const QPersistentModelIndex & index : qAsConst(d->mBusyIndexSet)) {
         update(index);
     }
 }
