@@ -55,7 +55,7 @@ static Exiv2::ExifData::const_iterator findDateTimeKey(const Exiv2::ExifData& ex
         << Exiv2::ExifKey("Exif.Image.DateTime");
 
     Exiv2::ExifData::const_iterator it, end = exifData.end();
-    Q_FOREACH(const Exiv2::ExifKey& key, lst) {
+    for (const Exiv2::ExifKey& key : lst) {
         it = exifData.findKey(key);
         if (it != end) {
             return it;
