@@ -119,7 +119,8 @@ void ThumbnailProviderTest::testLoadLocal()
 
     // Create a list of items which will be thumbnailed
     KFileItemList list;
-    Q_FOREACH(const QFileInfo & info, dir.entryInfoList(QDir::Files)) {
+    const auto entryInfoList = dir.entryInfoList(QDir::Files);
+    for (const QFileInfo & info : entryInfoList) {
         QUrl url("file://" + info.absoluteFilePath());
         KFileItem item(url);
         list << item;
@@ -139,12 +140,12 @@ void ThumbnailProviderTest::testLoadLocal()
     QDir thumbnailDir = ThumbnailProvider::thumbnailBaseDir(ThumbnailGroup::Normal);
     // There should be one file less because small.png is a png and is too
     // small to have a thumbnail
-    QStringList entryList = thumbnailDir.entryList(QStringList("*.png"));
+    const QStringList entryList = thumbnailDir.entryList(QStringList("*.png"));
     QCOMPARE(entryList.count(), mSandBox.mSizeHash.size() - 1);
 
     // Check thumbnail keys
     QHash<KFileItem, QHash<QString, QString> > thumbnailHash;
-    Q_FOREACH(const QString& name, entryList) {
+    for (const QString& name : entryList) {
         QImage thumb;
         QVERIFY(thumb.load(thumbnailDir.filePath(name)));
 
@@ -153,7 +154,7 @@ void ThumbnailProviderTest::testLoadLocal()
         QVERIFY(!item.isNull());
 
         QSize originalSize = mSandBox.mSizeHash.value(item.url().fileName());
-        uint mtime = item.time(KFileItem::ModificationTime).toTime_t();
+        uint mtime = item.time(KFileItem::ModificationTime).toSecsSinceEpoch();
 
         if (mtime == uint(-1)) {
             // This happens from time to time on build.kde.org, but I haven't
@@ -162,7 +163,7 @@ void ThumbnailProviderTest::testLoadLocal()
             qWarning() << "mtime == -1 for url" << url << ". This should not happen!";
             qWarning() << "errno:" << errno << "message:" << strerror(errno);
             qWarning() << "QFile::exists(" << url.toLocalFile() << "):" << QFile::exists(url.toLocalFile());
-            qWarning() << "Recalculating mtime" << item.time(KFileItem::ModificationTime).toTime_t();
+            qWarning() << "Recalculating mtime" << item.time(KFileItem::ModificationTime).toSecsSinceEpoch();
             QFAIL("Invalid time for test KFileItem");
         }
 
@@ -265,7 +266,8 @@ void ThumbnailProviderTest::testRemoveItemsWhileGenerating()
 
     // Create a list of items which will be thumbnailed
     KFileItemList list;
-    Q_FOREACH(const QFileInfo & info, dir.entryInfoList(QDir::Files)) {
+    const auto entryInfoList = dir.entryInfoList(QDir::Files);
+    for (const QFileInfo & info : entryInfoList) {
         QUrl url("file://" + info.absoluteFilePath());
         KFileItem item(url);
         list << item;
